@@ -6,7 +6,7 @@ no warnings 'redefine';
 use Socket;
 use base 'Exporter';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our @EXPORT_OK = ('connect', 'wrap_connection');
 
 # cache
@@ -590,19 +590,22 @@ description see above.
 	# we can wrap connection for separate object
 	# if package internally uses IO::Socket for connections (for most this is true)
 	
-	use v5.10;
 	use IO::Socket::Socks::Wrapper 'wrap_connection';
-	use Mojo::UserAgent;
+	use Net::SMTP;
 	
-	my $ua = wrap_connection(Mojo::UserAgent->new, {
+	my $smtp = wrap_connection(Net::SMTP->new('mailhost'), {
 		ProxyAddr => 'localhost',
 		ProxyPort => 1080,
 		SocksDebug => 1
 	});
 	
-	# $ua now uses socks5 proxy for connections
-	say $ua->get('http://www.google.com')->success->code;
-
+	# $smtp now uses socks5 proxy for connections
+	$smtp->to('postmaster');
+	$smtp->data();
+	$smtp->datasend("To: postmaster\n");
+	$smtp->datasend("\n");
+	$smtp->datasend("A simple test message\n");
+	$smtp->dataend();
 
 =head4 Integration with event loops
 
@@ -627,7 +630,8 @@ when $handle will become ready for writing.
 
 This parameter is optional.
 
-Let's start example to make it clear. For our example we will use Mojo::IOLoop
+Let's start example to make it clear. For our example we will use some fictional IO loop called C<Some::IOLoop>, which has same methods
+and behavior as L<Mojo::IOLoop>
 
 Beginning looks like
 
@@ -646,7 +650,7 @@ Here in the sub you can define some variable which you will use in the closures
 =over
 
 			# ...
-			my $reactor = Mojo::IOLoop->singleton->reactor;
+			my $reactor = Some::IOLoop->singleton->reactor;
 			
 			return {
 				init_io_watcher => sub {
